@@ -1,6 +1,5 @@
 import sys, os
 import requests
-from . import helper
 import smtplib, socket
 import json, re, imghdr
 from pathlib import Path
@@ -8,6 +7,7 @@ from os.path import exists
 from os.path import basename
 from getpass import getuser
 from subprocess import call
+from subprocess import getoutput
 from . import email_checker as mc
 from email.message import EmailMessage
 from tempfile import NamedTemporaryFile
@@ -20,6 +20,7 @@ HTML_FILE = (Path(__file__).parent / "html_message.html")
 MESSAGE_STR = " Your message ".center(14 + 22 * 2, '=')
 EMAIL_PATTERN = r"^\s*[\w\._%+-]+@[\w\.-]+\.\w+\s*$"
 SEND_TO_STR = r"//↓↓↓↓ Send to ↓↓↓↓\\"
+VERSION = getoutput("pip freeze | grep mailshell").split("==")[1]
 
 def connect_to_data():
 	if exists(USER_DATA): return
@@ -47,11 +48,23 @@ def user_data(mode, obj=None):
 	with open(USER_DATA, 'w') as data:
 		json.dump(obj, data, indent=2)
 
-def html_message(mode):
+def html_message(mode, filename=None):
 	if mode == 'GET':
 		if not exists(HTML_FILE): return
 		with open(HTML_FILE, 'r') as f:
 			return f.read().strip()
+
+	if filename:
+		if not exists(filename):
+			self.__error_file_not_found(filename)
+			return
+		with open(filename) as html:
+			content = html.read().strip()
+		if not content: return
+		with open(HTML_FILE, 'w') as html:
+			html.write(content)
+		return
+
 	call(['nano', HTML_FILE])
 	with open(HTML_FILE, 'r') as html:
 		if not html.read().strip(): os.remove(HTML_FILE)
@@ -59,7 +72,7 @@ def html_message(mode):
 def update_warning():
 	response = requests.get("https://pypi.org/pypi/mailshell/json")
 	current_version = response.json()['info']['version']
-	if helper.VERSION == current_version:
+	if VERSION == current_version:
 		return ""
 	warning = f"\n\x1b[33mWARNING: new version available [{current_version}]\n"
 	warning += "See 'pip3 install -U mailshell' to update.\x1b[0m\n"
@@ -105,18 +118,17 @@ class Mailshell():
 			"login": self.log_in,
 			"cred": self.credentials,
 			"new": self.new_message,
-			"edit": self.edit_message,
+			"set": self.edit_message,
 			"html": self.add_html,
 			"content": self.show_content,
 			"send": self.send_message,
 			"to": self.message_to,
 			"subject": self.set_subject,
 			"from": self.set_from,
-			"get": self.get_text,
 			"add": self.add_file,
 			"rm": self.remove_file,
-			"check": self.check_mail_box,
-			"sch": self.display_sc,
+			"check": self.checker,
+			"delete": self.checker,
 			"help": helpme,
 			"logout": self.log_out
 		}
@@ -160,7 +172,7 @@ class Mailshell():
 				if strp: text = text.strip()
 				return text
 
-	def log_in(self):
+	def log_in(self, args=None):
 		print('\nLog in:')
 		address = input("> Email address: ").strip()
 		password = input("> App password: ").strip()
@@ -187,12 +199,12 @@ class Mailshell():
 
 		print("\x1b[32mYou have been successfully logged in.\x1b[0m\n")
 
-	def log_out(self):
+	def log_out(self, args):
 		if not self.__has_user(): return
 		os.remove(USER_DATA)
 		print("\nYou have logged out.\n")
 
-	def credentials(self):
+	def credentials(self, args):
 		user = User()
 		user.get_user()
 		if not user:
@@ -201,19 +213,22 @@ class Mailshell():
 		print("\nEmail address:       " + user.address)
 		print("Email app password:  " + user.app_password, '\n')
 
-	def new_message(self):
+	def new_message(self, args):
 		if not self.__has_user(): return
 		print("\nCreating new message:")
 		data = user_data('GET')
-		data["message"]["subject"] = self.set_subject(True) 
-		data["message"]["from"] = self.set_from(True)
+		data["message"]["subject"] = self.set_subject(allowed=True) 
+		data["message"]["from"] = self.set_from(allowed=True)
 		data["message"]["text"] = ""
 		data["message"]["attachments"] = []
 		user_data('POST', data)
 		try: os.remove(HTML_FILE)
 		except: pass
 
-	def edit_message(self):
+	def edit_message(self, args):
+		if args.file:
+			self.get_text(args)
+			return
 		data = user_data('GET')
 		if not data["message"]["subject"]:
 			self.__error_create_message()
@@ -221,11 +236,11 @@ class Mailshell():
 		data["message"]["text"] = self.__get_multiline_input(data["message"]["text"])
 		user_data('POST', data)
 
-	def add_html(self):
+	def add_html(self, args):
 		if not self.__has_message(): return
-		html_message('POST')
+		html_message('POST', args.file)
 
-	def set_subject(self, allowed=False):
+	def set_subject(self, args=None, allowed=False):
 		data = user_data('GET')
 		subj = data["message"]["subject"]
 		if not allowed:
@@ -242,7 +257,7 @@ class Mailshell():
 				break
 			print("You have to set a Subject to your message!")
 
-	def set_from(self, allowed=False):
+	def set_from(self, args=None, allowed=False):
 		data = user_data('GET')
 		sdr = data["message"]["from"]
 		if not allowed:
@@ -257,52 +272,67 @@ class Mailshell():
 		data["message"]["from"] = sdr
 		user_data('POST', data)
 	
-	def get_text(self, file_path=''):
+	def get_text(self, args):
 		data = user_data('GET')
 		if not data["message"]["subject"]:
 			self.__error_create_message()
 			return
-		if not exists(file_path):
-			self.__error_file_not_found(file_path)
+		if not exists(args.file):
+			self.__error_file_not_found(args.file)
 			return
-		with open(file_path, 'r') as f:
+		with open(args.file, 'r') as f:
 			data["message"]["text"] += f.read()
 			user_data('POST', data)
 
-	def add_file(self, file_path=''):
+	def add_file(self, args):
 		if not self.__has_message(): return
 		data = user_data('GET')
-		if not exists(file_path):
-			self.__error_file_not_found(file_path)
+		if not exists(args.file):
+			self.__error_file_not_found(args.file)
 			return
-		if os.path.isdir(file_path):
+		if os.path.isdir(args.file):
 			print(f"\n'{file_path}' is a folder not file.\n")
 			return
-		data["message"]["attachments"].append(os.path.abspath(file_path))
+		data["message"]["attachments"].append(os.path.abspath(args.file))
 		user_data('POST', data)
 
-	def remove_file(self, filename=''):
+	def remove_file(self, args):
 		if not self.__has_message(): return
 		data = user_data('GET')
-		if filename == '*':
+		if args.all:
 			data["message"]["attachments"] = []
 			user_data('POST', data)
 			print("all files are removed from the message.")
 			return 
 		try:
-			data["message"]["attachments"].remove(os.path.abspath(filename))
+			data["message"]["attachments"].remove(os.path.abspath(args.file))
 			user_data('POST', data)
-			print(basename(filename), "is removed.")
-		except ValueError: print(f"ERROR: '{filename}' is not in your message.")
+			print(basename(args.file), "is removed.")
+		except ValueError: print(f"ERROR: '{args.file}' is not in your message.")
 
-	def show_content(self):
+	def show_content(self, args):
 		data = user_data('GET')
 		if not data["message"]["subject"]:
 			self.__error_create_message()
 			return
+
+		subject, sender, text, attachments = data["message"].values()
+		if args.files or args.images:
+			print("Message attachments:")
+			if args.files:
+				print("[FILES]")
+				fls = [f for f in attachments if not imghdr.what(f)]
+				if fls: print("\t" + '\n\t'.join(fls))
+				else: print("\tNo files.")
+			if args.images:
+				print("[IMAGES]")
+				imgs = [i for i in attachments if imghdr.what(i)]
+				if imgs: print("\t" + '\n'.join(imgs))
+				else: print("\tNo images.")
+			return
+
 		line = '-' * len(MESSAGE_STR)
 		content = '\n' + MESSAGE_STR + '\n'
-		subject, sender, text, attachments = data["message"].values()
 		content += f"Subject:  {subject}\nFrom:     {sender}\n"
 		if exists(HTML_FILE): text = html_message('GET')
 		content += f"\n{text}\n"
@@ -312,22 +342,20 @@ class Mailshell():
 		show(content + '\n' + line)
 		print("Use 'msl send' to send your message.\n")
 
-	def check_mail_box(self):
+	def checker(self, args):
 		user = User()
 		user.get_user()
 		if not user:
 			self.__error_login_first()
 			return
 		try:
-			mc.check(user)
+			if args.command == "check": mc.check(user, args)
+			else: mc.delete(user, args)
 			print(update_warning())
 		except socket.gaierror:
 			self.__error_connection()
 
-	def display_sc(self):
-		show(helper.IMAP_CRITERIAS)
-
-	def message_to(self):
+	def message_to(self, args=None):
 		if not self.__has_user(): return
 		data = user_data('GET')
 		pre = SEND_TO_STR + '\n' + '\n'.join(data["contacts"])
@@ -338,7 +366,7 @@ class Mailshell():
 		user_data('POST', data)
 		return contacts
 		  
-	def send_message(self):
+	def send_message(self, args):
 		user = User()
 		user.get_user()
 		data = user_data('GET')
@@ -346,9 +374,10 @@ class Mailshell():
 		if not subject:
 			self.__error_create_message()
 			return
-		contacts = self.message_to()
+		if args.to: contacts = [args.to]
+		else: contacts = self.message_to()
 		if not contacts:
-			print("You have no receivers: type 'msl to' to set your contacts.")
+			print("\nYou have no receivers: type 'msl to' to set your contacts.\nOr use 'msl send -T [EMAIL]' to send it to a specific email.\n")
 			return
 		try:
 			print("\nConnecting..")
@@ -384,23 +413,17 @@ class Mailshell():
 		except socket.gaierror:
 			self.__error_connection()
 	def __getitem__(self, args):
-		cmd, f = args
-		if cmd in self.commands:
-			connect_to_data()
-			if f: self.commands[cmd](f)
-			else: self.commands[cmd]()
+		connect_to_data()
+		self.commands[args.command](args)
 		
 
 
-def run(arg=None):
+def run(args=None):
 	SHELL = Mailshell()
-	if not arg.command:
-		if arg.version: print("Mailshell", f"[ {helper.VERSION} ]")
+	if not args.command:
+		if args.version: print("Mailshell", f"[ {VERSION} ]")
 		else: helpme()
 		return
 
-	try: command = [arg.command, arg.file]
-	except AttributeError: command = [arg.command, None]
-	if command[0] == "rm" and arg.all: command[1] = "*"
-	SHELL[command]
+	SHELL[args]
 
